summaryrefslogtreecommitdiff
path: root/lib/parallelizingdaemon.php
diff options
context:
space:
mode:
Diffstat (limited to 'lib/parallelizingdaemon.php')
-rw-r--r--lib/parallelizingdaemon.php22
1 files changed, 11 insertions, 11 deletions
diff --git a/lib/parallelizingdaemon.php b/lib/parallelizingdaemon.php
index dc28b5643..517115de0 100644
--- a/lib/parallelizingdaemon.php
+++ b/lib/parallelizingdaemon.php
@@ -1,6 +1,6 @@
<?php
/**
* Laconica, the distributed open-source microblogging tool
*
* Base class for making daemons that can do several tasks in parallel.
*
@@ -20,15 +20,15 @@
* along with this program. If not, see <http://www.gnu.org/licenses/>.
*
* @category Daemon
- * @package Laconica
- * @author Zach Copley <zach@controlyourself.ca>
- * @author Evan Prodromou <evan@controlyourself.ca>
- * @copyright 2009 Control Yourself, Inc.
+ * @package StatusNet
+ * @author Zach Copley <zach@status.net>
+ * @author Evan Prodromou <evan@status.net>
+ * @copyright 2009 StatusNet, Inc.
* @license http://www.fsf.org/licensing/licenses/agpl-3.0.html GNU Affero General Public License version 3.0
- * @link http://laconi.ca/
+ * @link http://status.net/
*/
-if (!defined('LACONICA')) {
+if (!defined('STATUSNET') && !defined('LACONICA')) {
exit(1);
}
@@ -38,11 +38,11 @@ declare(ticks = 1);
* Daemon able to spawn multiple child processes to do work in parallel
*
* @category Daemon
- * @package Laconica
- * @author Zach Copley <zach@controlyourself.ca>
- * @author Evan Prodromou <evan@controlyourself.ca>
+ * @package StatusNet
+ * @author Zach Copley <zach@status.net>
+ * @author Evan Prodromou <evan@status.net>
* @license http://www.fsf.org/licensing/licenses/agpl-3.0.html GNU Affero General Public License version 3.0
- * @link http://laconi.ca/
+ * @link http://status.net/
*/
class ParallelizingDaemon extends Daemon
@@ -1,6 +1,6 @@
<?php
/**
- * Laconica, the distributed open-source microblogging tool
+ * StatusNet, the distributed open-source microblogging tool
*
* Base class for making daemons that can do several tasks in parallel.